@@ -59,7 +59,7 @@ proc ouvrir {srv fich} {
    }
    if { $iret == 0 } {
       ashare::pointeur off
-      set ftmp [file join $astk::tmpdir .file_open]
+      set ftmp [get_tmpname .file_open]
       file delete -force $ftmp
       set iret [ashare::rcp_cmd astk::config $srv $fich -1 $ftmp action .]
       if { $iret == 0 && [file exists $ftmp] } {
@@ -154,7 +154,7 @@ proc enregistrer {srv fich} {
       set astk::profil(serv_profil) $srv
       set astk::profil(nom_profil) $fich
       # ecrire le fichier
-      set ftmp [file join $astk::tmpdir .file_save]
+      set ftmp [get_tmpname .file_save]
       set idsav [open $ftmp w]
       set ind [array get astk::profil]
       set n [expr [llength $ind] / 2]
@@ -268,6 +268,7 @@ proc copie_prof { } {
 #################################################################
 proc importer { type { append "non"}} {
    global getValue_val
+   set typin $type
    switch -exact -- $type {
       astk_serv -
       rex -
@@ -314,18 +315,22 @@ proc importer { type { append "non"}} {
       # prparation de la ligne de commande  excuter
       set lcmd ""
       set argu ""
+      set ftmp [get_tmpname .get_export]
+      set idexp [open $ftmp w]
+      write_server_infos $idexp $srv
+      close $idexp
       # as_run --get_export testcase
-      append lcmd [file join $astk::config($srv,rep_serv) "bin" as_run]
-      append lcmd " --get_export"
+      append lcmd [file join $ashare::prefix "bin" as_run]
+      append lcmd " --proxy --get_export --schema=[get_schema $srv get_export] $ftmp"
       append lcmd " --vers=$astk::profil(version)"
       append lcmd " $tst"
       append lcmd [ashare::get_glob_args]
       # execution
       change_status "[ashare::mess ihm 49]..."
-      set iret [ ashare::rexec_cmd $srv astk::config $lcmd $argu 0 out .]
+      set iret [ ashare::rexec_cmd -1 astk::config $lcmd $argu 0 out . progress]
       if { $iret == 0 } {
          set srv -1
-         set fich [file join $astk::tmpdir .file_tst_import]
+         set fich [get_tmpname .file_tst_import]
          set idsav [open $fich w]
          puts $idsav $out
          close $idsav
@@ -345,6 +350,11 @@ proc importer { type { append "non"}} {
    if { $iret == 0 } {
    # import
       set iret [import_from $type $srv $fich $append $nouveau]
+      if { $typin == "test" } {
+         for {set i 0} { $i < $astk::profil(etude,nbfic) } {incr i} {
+             set astk::profil(etude,fich,$i,serv) $astk::profil(serveur)
+         }
+      }
    }
    if { $ashare::dbg >= 4 } {
       ashare::log "<DEBUG> (importer) retour : $iret"
@@ -352,7 +362,7 @@ proc importer { type { append "non"}} {
    if       { $iret == 2 } {
       tk_messageBox -message [ashare::mess info 16] -type ok -icon info
    } elseif { $iret == 4 } {
-      tk_messageBox -message [ashare::mess info 4 $astk::config($srv,nom_complet):$fich] -type ok -icon info
+      tk_messageBox -message [ashare::mess ihm 360] -type ok -icon info
    } elseif { $iret != 0 } {
       tk_messageBox -message [ashare::mess ihm 136] -type ok -icon info
    }
@@ -367,7 +377,7 @@ proc import_from { type srv fich { append "non" } {nouveau "oui"}} {
       nouveau NON
    }
 #
-   set ftmp [file join $astk::tmpdir .file_import]
+   set ftmp [get_tmpname .file_import]
    set iret [ashare::rcp_cmd astk::config $srv $fich -1 $ftmp action .]
    if { $iret == 0 && [file exists $ftmp] } {
       if { $append == "non" && $nouveau == "oui" } {
@@ -447,7 +457,7 @@ proc exporter { type srv fich {verif "oui"} {tout_dist "non"}} {
       }
       if { $iret < 4 } {
          change_status "[ashare::mess ihm 123]..."
-         set ftmp [file join $astk::tmpdir .file_export]
+         set ftmp [get_tmpname .file_export]
          set iret [export_$type $ftmp $tout_dist $verif]
          if { $iret != 4 } {
             set kret [ashare::rcp_cmd astk::config -1 $ftmp $srv $fich action .]
@@ -475,33 +485,29 @@ proc exporter { type srv fich {verif "oui"} {tout_dist "non"}} {
 proc insert_in_db {} {
    # on prend un .export bidon
    set astk::profil(serv_fich_export) -1
-   set astk::profil(nom_fich_export) [file join $astk::tmpdir bidon.export]
-   set iret [exporter astk_serv $astk::profil(serv_fich_export) $astk::profil(nom_fich_export)]
+   set fexp [get_tmpname insert_in_db]
+   # l'extension est obligatoire au moment de l'export
+   append fexp ".export"
+   set astk::profil(nom_fich_export) $fexp
+   set iret [exporter astk_serv -1 $astk::profil(nom_fich_export)]
    if { $iret == 0 } {
    # indices ihm
       set serv $astk::inv(serv,$astk::profil(serveur))
    # prparation de la ligne de commande  excuter
       set lcmd ""
       set argu ""
-      # as_exec fichier_export
-      append lcmd [file join $astk::config($serv,rep_serv) "bin" as_run]
-      append lcmd " --insert_in_db"
-      append lcmd " --display=$ashare::DISPLAY"
+      append lcmd [file join $ashare::prefix "bin" as_run]
+      append lcmd " --proxy --insert_in_db --schema=[get_schema $serv insert_in_db]"
       append lcmd [ashare::get_glob_args]
-      if { $astk::config($serv,islocal) != "oui"
-      || [ashare::meme_machine $astk::config($serv,nom_complet) $astk::config($astk::profil(serv_fich_export),nom_complet)] != 1
-      || $astk::config($serv,login) != $astk::config($astk::profil(serv_fich_export),login) } {
-         append argu "$astk::config($astk::profil(serv_fich_export),login)@$astk::config($astk::profil(serv_fich_export),nom_complet):"
-      }
       append argu $astk::profil(nom_fich_export)
-   
+
       if { $ashare::dbg >= 4 } {
          ashare::log "<DEBUG> (insert_in_db) $lcmd + $argu"
       }
-   
+
    # execution
       change_status "[ashare::mess ihm 49]..."
-      set jret [ ashare::rexec_cmd $serv astk::config $lcmd $argu 0 out .]
+      set jret [ ashare::rexec_cmd -1 astk::config $lcmd $argu 0 out . progress]
       if { $jret != 0 } {
       # pb lancement de as_run
          ashare::mess "erreur" 3 $lcmd $jret $out
@@ -577,19 +583,24 @@ proc check_exist_type { } {
       }
       if { $astk::profil($var2) == "oui" } {
          for {set i 0} { $i < $astk::profil($var,nbfic) } {incr i} {
-            # numro du type dans astk::UL
+            # numro du type dans astk::UL_ref
             set typdef "X"
             set nul 0
-            for {set nul 0} {$nul < $astk::UL($var,nbre)} {incr nul} {
-               if { $astk::profil($var,fich,$i,type) == $astk::UL($var,$nul,nom) } {
-                  set typdef $astk::UL($var,$nul,FR)
+            for {set nul 0} {$nul < $astk::UL_ref($var,nbre)} {incr nul} {
+               if { $astk::profil($var,fich,$i,type) == $astk::UL_ref($var,$nul,nom) } {
+                  set typdef $astk::UL_ref($var,$nul,FR)
                   break
                }
             }
+            # si fichier source
+            # ou ( surcharge (exec/cmde/ele/btc) en D mais pas R
+            #      et pas agla
+            #      et pas multiple car relocalis )
             if { ( $var != "surcharge" && $astk::profil($var,fich,$i,donnee) )
               || ( $var == "surcharge" && $astk::profil($var,fich,$i,donnee)
                    && $astk::profil($var,fich,$i,resultat) == 0
-                   && $astk::profil(agla) != "oui" ) } {
+                   && $astk::profil(agla) != "oui"
+                   && [in_no_values $astk::profil(opt_val,multiple)] ) } {
                # serveur
                set srv $astk::inv(serv,$astk::profil($var,fich,$i,serv))
                # chemin du fichier
@@ -658,12 +669,12 @@ proc check_exist_type { } {
                      change_status $msg
                      tk_messageBox -message $msg -type ok -icon info
                      set iret 4
-                  } elseif { [regexp $typ $astk::UL($var,$nul,FR)] == 0 } {
+                  } elseif { [regexp $typ $astk::UL_ref($var,$nul,FR)] == 0 } {
                   # pas du type requis
-                     if { $astk::UL($var,$nul,FR) == "F" } {
-                        set msg [ashare::mess erreur 35 $astk::UL($var,$nul,nom)]
+                     if { $astk::UL_ref($var,$nul,FR) == "F" } {
+                        set msg [ashare::mess erreur 35 $astk::UL_ref($var,$nul,nom)]
                      } else {
-                        set msg [ashare::mess erreur 36 $astk::UL($var,$nul,nom)]
+                        set msg [ashare::mess erreur 36 $astk::UL_ref($var,$nul,nom)]
                      }
                      change_status $msg
                      tk_messageBox -message $msg -type ok -icon info
@@ -686,8 +697,11 @@ proc import_astk_serv { fich append } {
    # compteurs de fichier etude, tests, source, surcharge
    set idp [open $fich r]
    set perc 100
+   # voir si la valeur change
+   set ini_serv $astk::profil(serveur)
+   set ini_node $astk::profil(noeud)
    while { [eof $idp] != 1 } {
-      gets $idp line 
+      gets $idp line
       if { [regexp {^[ ]*A[ ]+([-a-z_A-Z0-9]*)[ ]+(.*[^ $])} $line bid mot val] == 1 } {
       # arguments
          switch -exact -- $mot {
@@ -827,6 +841,13 @@ proc import_astk_serv { fich append } {
             mclient -
             follow_output -
             liste_test -
+            platform -
+            studyid -
+            aster_root -
+            proxy_dir -
+            protocol_exec -
+            protocol_copyfrom -
+            protocol_copyto -
             uclient {
             # valeurs ignorees
             }
@@ -859,6 +880,13 @@ proc import_astk_serv { fich append } {
                }
             }
          }
+         if { $astk::profil(serveur) != $ini_serv \
+           && $astk::profil(noeud) == $ini_node } {
+            set is $astk::inv(serv,$astk::profil(serveur))
+            if { $is > 0 } {
+               set astk::profil(noeud) $astk::config($is,noeud,0)
+            }
+         }
 
       } elseif {[regexp {^[ ]*([FR]+)[ ]+([-a-z_A-Z0-9]*)[ ]+(.*)[ ]+([DRC]+)[ ]*([0-9]*)} $line bid cFR ctyp val flag ul] == 1} {
          # nom de fichiers ou rpertoires sans blanc
@@ -874,14 +902,14 @@ proc import_astk_serv { fich append } {
             set iret 2
          }
          if { $ind != -1 } {
-            if { $ctyp != "libr" && $astk::UL($var,$ind,num) != $ul } {
+            if { $ctyp != "libr" && $astk::UL_ref($var,$ind,num) != $ul } {
                ashare::log "<INFO> (import_astk_serv) Type et UL ne correspondent pas pour ce fichier :\n$ctyp ! $val ! $flag ! $ul"
                set ctyp libr
                set iret 2
             }
          }
          set i $astk::profil($var,nbfic)
-         set srv $astk::profil(serveur)
+         set srv $astk::local_server
          set cfic $val
          if { [regexp {(.+)@(.+):(.+)} $val bid user srv cfic] } {
             set is [valid_serveur $srv "" nom_complet]
@@ -931,8 +959,8 @@ proc is_type { typ } {
       if { $res != 0 } {
          break
       } else {
-         for {set i 0} {$i < $astk::UL($var,nbre)} {incr i} {
-            if { $typ == $astk::UL($var,$i,nom) } {
+         for {set i 0} {$i < $astk::UL_ref($var,nbre)} {incr i} {
+            if { $typ == $astk::UL_ref($var,$i,nom) } {
                set res $var
                set ind $i
                break
