@@ -34,7 +34,7 @@ from asrun.distrib      import DistribTestTask
 from asrun.repart       import get_hostrc
 from asrun.common_func  import get_tmpname
 from asrun.maintenance  import get_aster_version, repr_vers, get_diagnostic
-from asrun.common.utils import get_list, now
+from asrun.common.utils import get_list, now, YES_VALUES
 
 
 fmt_head = '%s %s %s %s %s %s' % (_(u"testcase").center(12), _(u"result").center(18),
@@ -128,7 +128,7 @@ def RunAstout(run, conf, prof, mpi_info, numthread='auto', **kargs):
     nbtest = len(list_tests)
 
     # should we run only nook tests ?
-    if run['only_nook']:
+    if run['only_nook'] or prof['only_nook'][0] in YES_VALUES:
         l_dirs = reptest + [resutest]
         old_run_result = get_diagnostic(run, build, l_dirs, list_tests)
         run.DBG('get_diagnostic result', old_run_result, all=True)
