@@ -104,14 +104,16 @@ class BatchSystem(object):
             'nomjob'    : self.prof['nomjob'][0],
             'tpsjob'    : int(float(self.prof['tpsjob'][0])),   # in minutes
             'tpmax'     : self.prof.args.get('tpmax', 1),       # in seconds
-            'memjob'    : self.prof['memjob'][0],
+            'memjob'    : int(float(self.prof['memjob'][0])),
             'clasgr'    : self.prof['classe'][0],
             'depart'    : self.prof['depart'][0],
+            'after_job' : self.prof['after_job'][0],
             'mpi_nbcpu' : self.prof['mpi_nbcpu'][0],
             'mpi_nbnoeud': self.prof['mpi_nbnoeud'][0],
             'custom'    : self.prof['batch_custom'][0],
         })
         dico['batch_ini'] = self.prof['batch_ini'][0] or dico['batch_ini']
+        dico['bsub'] = self.prof['batch_sub'][0] or dico['bsub']
 
         group = self.prof['batch_queue_group'][0] or self.run.get('batch_queue_group', '')
         if dico['clasgr'] != '' and dico['clasgr'] in group.split():
@@ -276,6 +278,8 @@ class LSF(BatchSystem):
             txt.append('''#BSUB -q "%(classe)s"''')
         if self.dict_info.get('depart'):
             txt.append("#BSUB -b %(depart)s")
+        if self.dict_info.get('after_job'):
+            txt.append("#BSUB -w ended(%(after_job)s)")
         if self.dict_info.get('custom'):
             txt.append("#BSUB %(custom)s")
         # core script
@@ -348,6 +352,8 @@ class PBS(BatchSystem):
             txt.append('''#PBS -q "%(classe)s"''')
         if self.dict_info.get('depart'):
             txt.append("#PBS -a %(depart)s")
+        if self.dict_info.get('after_job'):
+            txt.append("#PBS -W depend=after:%(after_job)s")
         if self.dict_info.get('custom'):
             txt.append("#PBS %(custom)s")
         # core script
@@ -438,6 +444,8 @@ class SGE(BatchSystem):
             txt.append('''#$ -q "%(classe)s"''')
         if self.dict_info.get('depart'):
             txt.append("#$ -a %(depart)s")
+        if self.dict_info.get('after_job'):
+            txt.append("#$ -hold_jid %(after_job)s")
         if self.dict_info.get('custom'):
             txt.append("#$ %(custom)s")
         # core script
@@ -489,7 +497,7 @@ class SLURM(BatchSystem):
     """for Slurm batch system."""
     bsub = 'sbatch'
     bjid = 'SLURM_JOB_ID'
-    bjob = 'squeue'
+    bjob = 'squeue -o "%i %P %t %M %N"'
     bkil = 'scancel'
     bsig = bkil
     cmdsig = '%(bsig)s --signal=%(signal)s --batch %(jobid)s'
@@ -528,6 +536,8 @@ class SLURM(BatchSystem):
             txt.append('''#SBATCH --partition="%(classe)s"''')
         if self.dict_info.get('depart'):
             txt.append("#SBATCH --begin=%(depart)s")
+        if self.dict_info.get('after_job'):
+            txt.append("#SBATCH --dependency=after:%(after_job)s")
         if self.dict_info.get('custom'):
             txt.append("#SBATCH %(custom)s")
 
@@ -554,12 +564,12 @@ class SLURM(BatchSystem):
             spl = line.pop().split()
             if len(spl) >= 2:
                 jobinf.queue = spl[1]
+            if len(spl) >= 3:
+                jobinf.state = self._conv_state.get(spl[2])
+            if len(spl) >= 4:
+                jobinf.cputime = dhms2s(spl[3])
             if len(spl) >= 5:
-                jobinf.state = self._conv_state.get(spl[4])
-            if len(spl) >= 6:
-                jobinf.cputime = dhms2s(spl[5])
-            if len(spl) >= 8:
-                jobinf.node = spl[7]
+                jobinf.node = spl[4]
         else:
             jobinf.state = 'ENDED'
         return jobinf
