@@ -37,7 +37,7 @@ from asrun.thread       import Task, TaskAbort, Dispatcher
 from asrun.mpi          import MPI_INFO
 from asrun.common_func  import get_tmpname
 from asrun.common.utils import re_search, YES_VALUES, unique_basename_remove
-from asrun.common.sysutils import is_newer
+from asrun.common.sysutils import is_newer, is_newer_mtime
 from asrun.system       import split_path
 
 from asrun.backward_compatibility import bwc_deprecate_class
@@ -394,7 +394,10 @@ class AsterBuild_Classic:
 
         # ----- if force is True, don't use ctime to skip a file
         force = force or self.run['force']
-        if not osp.exists(lib):
+        if osp.exists(lib):
+            mtlib = os.stat(lib).st_mtime
+        else:
+            mtlib = 0
             force = True
 
         # ----- work in repobj
@@ -418,7 +421,7 @@ class AsterBuild_Classic:
             clen = len(cmd[0])+1
             nadd = 0
             while len(files) > 0 and clen+len(files[0]) < self.run.system.MaxCmdLen-15:
-                if not force and is_newer(lib, files[0]):
+                if not force and is_newer_mtime(mtlib, files[0]):
                     nskip += 1
                     bid = files.pop(0)
                 else:
@@ -721,9 +724,10 @@ class AsterBuild_Classic:
         force = self.run['force']
 
         # ----- copy capy from REPREF
-        if osp.exists(self.conf['SRCCAPY'][0]):
-            self.run.Delete(self.conf['SRCCAPY'][0])
-        iret = self.run.Copy(self.conf['SRCCAPY'][0],
+        bascpy = osp.basename(self.conf['SRCCAPY'][0])
+        if osp.exists(bascpy):
+            self.run.Delete(bascpy)
+        iret = self.run.Copy(bascpy,
                 osp.join(REPREF, self.conf['SRCCAPY'][0]), verbose=True)
 
         # if 'capy' is in kargs
@@ -737,7 +741,7 @@ class AsterBuild_Classic:
             for occ in lobj:
                 obj = occ
                 if self.run.IsRemote(occ):
-                    obj = osp.join(self.conf['SRCCAPY'][0],
+                    obj = osp.join(bascpy,
                                   '__tmp__'+osp.basename(occ))
                     iret = self.run.MkDir(obj)
                     if self.run.IsDir(occ):
@@ -756,7 +760,7 @@ class AsterBuild_Classic:
                     mod, rep = self.GetCModif('capy', f)
                     # because filename is important, remove sha1 digest
                     mod = unique_basename_remove(mod)
-                    dest = osp.join(self.conf['SRCCAPY'][0], rep, mod + '.capy')
+                    dest = osp.join(bascpy, rep, mod + '.capy')
                     iret = self.run.Copy(dest, f, verbose=True)
                     if not rep in repcatapy:
                         self._mess(ufmt(_(u'unknown module name : %s'), rep), '<A>_ALARM')
@@ -775,7 +779,7 @@ class AsterBuild_Classic:
         if force or not osp.exists(osp.join(cmde, fcapy)):
             force = True
         else:
-            ltest = glob(osp.join(self.conf['SRCCAPY'][0], '*', '*.capy'))
+            ltest = glob(osp.join(bascpy, '*', '*.capy'))
             for f in ltest:
                 if not is_newer(osp.join(cmde, fcapy), f):
                     force = True
@@ -787,7 +791,7 @@ class AsterBuild_Classic:
         else:
             fo = open(fcapy, 'w')
             for rep in repcatapy:
-                lcapy = glob(osp.join(self.conf['SRCCAPY'][0], rep, '*.capy'))
+                lcapy = glob(osp.join(bascpy, rep, '*.capy'))
                 lcapy.sort()
                 for capy in lcapy:
                     fo2 = open(capy, 'r')
@@ -870,13 +874,13 @@ sys.exit(iret)
                         fo = open(cata_out, 'w')
                         # prendre l'entete
                         for rep in repcatapy[:1]:
-                            for capy in glob(osp.join(self.conf['SRCCAPY'][0], rep, '*.capy')):
+                            for capy in glob(osp.join(bascpy, rep, '*.capy')):
                                 txt0 = open(capy, 'r').read()
                                 txt2 = exp.sub(new, txt0)
                                 fo.write(txt2)
                         # reprendre les imports
                         for rep in repcatapy[1:]:
-                            for capy in glob(osp.join(self.conf['SRCCAPY'][0], rep, '*.capy')):
+                            for capy in glob(osp.join(bascpy, rep, '*.capy')):
                                 fo.write(get_txt_capy(capy))
                                 txt_orig.append(open(capy, 'r').read())
                         fo.write(os.linesep)
@@ -908,7 +912,7 @@ sys.exit(iret)
     def CompilEle(self, REPREF, reptrav, ele='', **kargs):
         """Compile elements catalogue as 'ele' from cata_ele.pickled.
         kargs must contain arguments for a Code_Aster execution (i.e. for PrepEnv)
-        and optionnaly :
+        and optionaly :
             cata    : a list of user's elements files
             unigest : GetUnigest dict with "CATSUPPR catalo module" entries
             pickled : use a different cata_ele.pickled (not in REPREF)
@@ -1028,7 +1032,7 @@ sys.exit(iret)
         cmd = [osp.join('.', osp.basename(kargs['exe']))]
         cmd.append(osp.join(self.conf['REPPY'][0], self.conf['ARGPYT'][0]))
         cmd.extend(self.conf['ARGEXE'])
-        cmd.append('-commandes fort.1 -memjeveux 8 -rep none -tpmax 60')
+        cmd.append('-commandes fort.1 -memjeveux 64 -tpmax 120')
         fo = open('fort.1', 'w')
         fo.write("""
 # COMPILATION DU CATALOGUE D'ELEMENT
@@ -1303,6 +1307,14 @@ def get_txt_capy(capy):
     keep.append('')
     return os.linesep.join(keep)
 
+_no_convergence_exceptions = (
+    'NonConvergenceError', 'EchecComportementError', 'PilotageError',
+)
+_contact_exceptions = (
+    'TraitementContactError', 'MatriceContactSinguliereError',
+    'BoucleGeometrieError', 'BoucleFrottementError', 'BoucleContactError',
+    'CollisionError', 'InterpenetrationError',
+)
 
 def _diag_erre(err, mess=False):
     """Diagnostic à partir du fichier '.erre'.
@@ -1310,6 +1322,7 @@ def _diag_erre(err, mess=False):
     Pour un fichier de message, 'ARRET NORMAL DANS FIN' est absent, donc on ne
     peut pas déterminer 'ok'.
     """
+    run = magic.run
     diag = None
     stop = False
     if err is None or not osp.exists(err):
@@ -1324,6 +1337,9 @@ def _diag_erre(err, mess=False):
 
         alarm = re_search(txt, pattern='^ *. *%s', string='<A>')
         fatal = re_search(txt, pattern='^ *. *%s', string='<F>')
+        exitcode = re_search(txt, pattern='^ *%s_EXIT_CODE = ([0-9]+)',
+                             string='<I>', result='value')
+        exitcode = exitcode and int(exitcode[0]) or 0
 
         if fatal:
             expir = re_search(txt, pattern='^ *. *%s',
@@ -1332,22 +1348,42 @@ def _diag_erre(err, mess=False):
                     string='<F> <SUPERVISEUR> ARRET SUR ERREUR(S) UTILISATEUR',
                     flag=re.IGNORECASE)
         else:
-            expir  = False
-            superv = False
+            expir = superv = False
 
         errs = re_search(txt, pattern='^ *. *%s', string='<S>')
 
         if errs:
             mem = re_search(txt, string='MEMOIRE INSUFFISANTE POUR ALLOUER', flag=re.IGNORECASE)
             arretcpu = re_search(txt, string='ARRET PAR MANQUE DE TEMPS CPU', flag=re.IGNORECASE) \
-                 or re_search(txt, pattern='^ *. *%s', string='ArretCPUError') \
+                 or re_search(txt, pattern='<%s>', string='ArretCPUError') \
                  or re_search(txt, string='timelimit expired', flag=re.IGNORECASE)
+            nonconverg = max([re_search(txt, pattern='<%s>', string=exc) \
+                              for exc in _no_convergence_exceptions])
+            contact = max([re_search(txt, pattern='<%s>', string=exc) \
+                              for exc in _contact_exceptions])
+        else:
+            mem = arretcpu = nonconverg = contact = False
 
         ok = (n_debut == n_fin and n_fin > 0) or mess
+        run.DBG('n_debut=%s, n_fin=%s, mess=%s : ok=%s' % (n_debut, n_fin, mess, ok))
+        run.DBG('alarm=%s, errs=%s, fatal=%s, exitcode=%s' % (alarm, errs, fatal, exitcode))
         if ok:
             diag = 'OK'
             if alarm:
                 diag = '<A>_ALARM'
+            if exitcode != 0:
+                errs = True
+        # "S" (recoverable) error
+        if errs:
+            diag = '<S>_ERROR'
+            if arretcpu:
+                diag = '<S>_CPU_LIMIT'
+            elif nonconverg:
+                diag = '<S>_NO_CONVERGENCE'
+            elif contact:
+                diag = '<S>_CONTACT_ERROR'
+            elif mem:
+                diag = '<S>_MEMORY_ERROR'
         # fatal error
         if fatal:
             diag = '<F>_ERROR'
@@ -1355,13 +1391,6 @@ def _diag_erre(err, mess=False):
                 diag = '<F>_SUPERVISOR'
             elif expir:
                 diag = '<F>_EXPIRED_VERS'
-        # "S" (recoverable) error
-        if errs:
-            diag = '<S>_ERROR'
-            if arretcpu:
-                diag = '<S>_CPU_LIMIT'
-            elif mem:
-                diag = '<S>_MEMORY_ERROR'
         if not ok or fatal or errs:
             stop = True
 
@@ -1422,7 +1451,7 @@ def _diag_mess(mess):
 
         else:
             # recherche de la levée non récupérée d'exception
-            arretcpu = re_search(txt, pattern='^ *. *%s', string='ArretCPUError') \
+            arretcpu = re_search(txt, pattern='<%s>', string='ArretCPUError') \
                  or re_search(txt, string='timelimit expired', flag=re.IGNORECASE)
             if arretcpu:
                 diag = '<S>_CPU_LIMIT'
