@@ -32,7 +32,7 @@ from asrun.core             import magic
 from asrun.mystring         import convert, print3, ufmt
 from asrun.job              import Func_actu, Func_tail, Del
 from asrun.build            import AsterBuild
-from asrun.config           import build_AsterConfig
+from asrun.config           import build_config_from_export
 from asrun.profil           import AsterProfil
 from asrun.system           import shell_cmd
 from asrun.execution        import build_test_export
@@ -218,7 +218,8 @@ class AsterCalcul(BaseCalcul):
         Allow to adapt prof object before customization."""
         # decode service called
         self.decode_special_service()
-
+        # add memory
+        self.add_memory()
         # allow customization of calcul object
         if self.run['schema_calcul']:
             schem = get_plugin(self.run['schema_calcul'])
@@ -249,6 +250,22 @@ class AsterCalcul(BaseCalcul):
         if self.serv not in self._supported_services:
             self.error(_(u'Unknown service : %s') % self.serv)
 
+    def add_memory(self):
+        """Add an amount of memory (MB) to the export parameters"""
+        if self.serv in ('parametric_study', 'agla'):
+            return
+        conf = build_config_from_export(self.run, self.prof)
+        self.run.DBG("memory to add: %s" % conf['ADDMEM'][0])
+        try:
+            addmem = float(conf['ADDMEM'][0])
+        except ValueError:
+            addmem = 0.
+        if not addmem:
+            return
+        memory = float(self.prof['memjob'][0] or 0.) / 1024. + addmem
+        self.prof.set_param_memory(memory)
+        self.run.DBG("new memory parameters: memjob=%s  memjeveux=%s",
+                     self.prof['memjob'][0], self.prof.args['memjeveux'])
 
     def on_mach_ref(self):
         """Are we on the reference server ?
@@ -382,6 +399,10 @@ export LOGNAME
 # message d'info
 printf %(message)r
 
+# protection du fort.6
+touch %(rep_trav)s/%(nomjob)s.$num_job.fort.6.%(m)s
+chmod 600 %(rep_trav)s/%(nomjob)s.$num_job.fort.6.%(m)s
+
 # lance l'exec
 %(as_run_cmd)s %(opts)s %(nomjob_p)s \
         --num_job=$num_job \
@@ -533,7 +554,7 @@ egrep -- '--- DIAGNOSTIC JOB :' %(rep_trav)s/%(nomjob)s.$num_job.fort.6.%(m)s |
 
             self.run.DBG('OUTPUT of as_exec_ref :', output, all=True)
 
-            self.jobid, self.queue, self.stuyid = parse_submission_result(output)
+            self.jobid, self.queue, self.studyid = parse_submission_result(output)
             if osp.exists(fbtc):
                 jret = self.run.Rename(fbtc, self.flash('script'))
             jret = self.run.Copy(self.flash('export'), self.prof.get_filename())
@@ -644,7 +665,7 @@ class AsterCalcTestcase(AsterCalcul):
         d_unig = None
         if lunig:
             unigest = lunig[0].path
-            conf = build_AsterConfig(self.run, ptest)
+            conf = build_config_from_export(self.run, ptest)
             build = AsterBuild(self.run, conf)
             d_unig = build.GetUnigest(unigest)
         prt = build_test_export(self.run, self.param['conf'], self.param['REPREF'],
@@ -715,6 +736,7 @@ class AsterCalcParametric(AsterCalcul):
         del prof['follow_output']
         del prof['rep_trav']
         del prof['detr_rep_trav']
+        del prof['depart']
         prof.Del('D', typ='distr')
         compress = prof.Get('R', typ='repe')[0]['compr']
         prof.Del('R', typ='repe')
