@@ -39,13 +39,14 @@ NO  = NO_VALUES[0]
 
 
 class Singleton(object):
-    """Singleton implementation in python.
-    """
+    """Singleton implementation in python."""
+    # add _singleton_id attribute to the class to be independant of import path used
     __inst = {}
     def __new__(cls, *args, **kargs):
-        if Singleton.__inst.get(cls) is None:
-            Singleton.__inst[cls] = object.__new__(cls, *args, **kargs)
-        return Singleton.__inst[cls]
+        cls_id = getattr(cls, '_singleton_id', cls)
+        if Singleton.__inst.get(cls_id) is None:
+            Singleton.__inst[cls_id] = object.__new__(cls)
+        return Singleton.__inst[cls_id]
 
 
 class Enum(object):
@@ -165,7 +166,6 @@ def _listsurcharge_u2mess(fsurch, lf):
     """
     header = """
       SUBROUTINE SURCHG(IFM)
-C --- IFM CONSERVE POUR LA COMPATIBILITE (DUMMY ARGUMENT)
       INTEGER IFM
       CHARACTER*80  VALK(%(nbfile)s)
       IFM = 1"""
@@ -595,3 +595,23 @@ __reg_prefix__ = re.compile('^[a-f0-9]{%d}\.' % (sha1('a').digest_size * 2), re.
 def unique_basename_remove(bname):
     """Remove the prefix added by unique_basename."""
     return __reg_prefix__.sub('', bname)
+
+def force_list(obj):
+    """Return 'obj' as a list object."""
+    if type(obj) not in (list, tuple):     # pas une liste
+        obj = [obj,]
+    return obj
+
+def force_couple(obj):
+    """Return 'obj' as a list of couples."""
+    if type(obj) not in (list, tuple):     # pas une liste
+        obj = [[obj, None],]
+    elif type(obj[0]) in (list, tuple):    # liste de listes
+        pass
+    else:
+        assert len(obj) == 2, 'not a couple : %s' % obj
+        obj = [obj,]
+    # verif
+    for i, val in enumerate(obj):
+        assert len(val) == 2, 'item %d is not a couple : %s' % (i, val)
+    return obj
