@@ -30,10 +30,9 @@ import cPickle
 import time
 from glob import glob
 
-from asrun.installation import aster_root
 from asrun.common.i18n import _
 from asrun.mystring     import print3, ufmt
-from asrun.config       import AsterConfig
+from asrun.config       import AsterConfig, build_config_of_version
 from asrun.build        import AsterBuild, unigest2dict
 from asrun.progress     import Progress
 
@@ -373,7 +372,7 @@ class MESSAGE_MANAGER(object):
                 mattyp = re.search('[\'\" ]+(.*?)[\+\'\" ]+', typ)
                 # variables and numbers (for exception) are allowed
                 if mattyp is not None and \
-                   mattyp.group(1) not in ('', 'A', 'I', 'E', 'S', 'F'):
+                   mattyp.group(1) not in ('', 'A', 'I', 'E', 'S', 'F', 'M', 'D'):
                    # may be '' for example STY//'+'
                     print3("Invalid message type (%s) for message '%s' in file %s" \
                         % (mattyp.group(1), msg, fich))
@@ -724,12 +723,11 @@ def GetMessageInfo(run, *args):
     """
     if not run.get('aster_vers'):
         run.parser.error(_(u"You must define 'default_vers' in 'aster' configuration file or use '--vers' option."))
-    REPREF = osp.join(aster_root, run['aster_vers'])
-    if not run.get('config'):
-        fconf = osp.join(REPREF, 'config.txt')
-    else:
-        fconf = osp.abspath(run['config'])
-    conf = AsterConfig(fconf, run)
+    REPREF = run.get_version_path(run['aster_vers'])
+    fconf = run.get('config')
+    if fconf:
+        fconf = osp.abspath(fconf)
+    conf = build_config_of_version(run, run['aster_vers'], fconf)
 
     if run['nolocal']:
         run.Mess(_(u'This operation only works on local source files. "--nolocal" option ignored'))
@@ -740,7 +738,6 @@ def GetMessageInfo(run, *args):
     else:
         run.Mess(_(u'Fortran 90 source files are not used on this machine (see %s)') \
                 % conf.filename, '<A>_ALARM')
-    bibpyt = conf['SRCPY'][0]
 
     args = list(args)
     named_actions = ('check', 'move',)
@@ -760,14 +757,18 @@ def GetMessageInfo(run, *args):
     if surch_pyt:
         surch_pyt = surch_pyt.split(',')
 
-    msgman = MESSAGE_MANAGER(repref=REPREF, fort=bibfor, pyt=bibpyt,
-                            cache_dict=osp.join(run['cache_dir'], 'messages_dicts.pick'),
-                            force=run['force'], verbose=run['verbose'],
-                            debug=run['debug'],
-                            surch_fort=surch_fort,
-                            surch_pyt =surch_pyt,
-                            unig      =run.get('unigest', None),
-                            )
+    pick_cache = 'messages_dicts.%s.pick' % (run['aster_vers'].replace(os.sep, '_'))
+    msgman = MESSAGE_MANAGER(repref=REPREF,
+                             fort=bibfor,
+                             pyt=conf['SRCPY'][0],
+                             capy=conf['SRCCAPY'][0],
+                             cache_dict=osp.join(run['cache_dir'], pick_cache),
+                             force=run['force'], verbose=run['verbose'],
+                             debug=run['debug'],
+                             surch_fort=surch_fort,
+                             surch_pyt =surch_pyt,
+                             unig      =run.get('unigest', None),
+                             )
     msgman.read_cata()
 
     if action == 'check':
