@@ -34,7 +34,7 @@ from asrun.common.i18n  import _
 from asrun.mystring     import print3, ufmt
 from asrun.profil       import AsterProfil
 from asrun.build        import AsterBuild
-from asrun.config       import build_AsterConfig
+from asrun.config       import build_config_from_export
 from asrun.maintenance  import get_aster_version
 from asrun.execution    import execute, copyfiles, build_export_from_files, add_all_results
 from asrun.mpi          import MPI_INFO
@@ -127,7 +127,7 @@ def RunAster(run, *args):
 
     # 1.2. get AsterConfig and AsterBuild objects
     REPREF = prof.get_version_path()
-    conf = build_AsterConfig(run, prof)
+    conf = build_config_from_export(run, prof)
     build = AsterBuild(run, conf)
     DbgPara = {
         'debug'     : { 'exe'    : conf['BIN_DBG'][0],
@@ -156,7 +156,8 @@ def RunAster(run, *args):
     iret = mpi.set_cpuinfo(prof['mpi_nbnoeud'][0], prof['mpi_nbcpu'][0])
     if iret == 1:
         run.Mess(ufmt(_(u"%s is not a MPI version of Code_Aster. "
-            "The number of nodes/processors asked will be ignored."), REPREF), "<A>_ALARM")
+            "The number of nodes/processors must be equal to 1."), REPREF),
+            "<F>_INVALID_PARAMETER")
     elif iret != 0:
         run.Mess(_(u"incorrect value for mpi_nbnoeud (%s) or mpi_nbcpu (%s)") \
             % (prof['mpi_nbnoeud'][0], prof['mpi_nbcpu'][0]), '<F>_INVALID_PARAMETER')
@@ -182,9 +183,9 @@ def RunAster(run, *args):
         run.ToDelete(reptrav)
 
     # 1.6. copy profile in rep_trav
-    kret = run.Copy(os.path.join(reptrav, jn+'.export'), fprof)
+    kret = run.Copy(osp.join(reptrav, jn+'.export'), fprof)
     # ... and config file as ./config.txt
-    conf.WriteConfigTo(os.path.join(reptrav, 'config.txt'))
+    conf.WriteConfigTo(osp.join(reptrav, 'config.txt'))
 
     # 1.7. debug/nodebug
     dbg = prof['debug'][0]
@@ -192,9 +193,9 @@ def RunAster(run, *args):
         dbg = 'nodebug'
 
     # 1.8. default values
-    exetmp  = os.path.join(REPREF, DbgPara[dbg]['exe'])
-    cmdetmp = os.path.join(REPREF, conf['BINCMDE'][0])
-    eletmp  = os.path.join(REPREF, conf['BINELE'][0])
+    exetmp  = osp.join(REPREF, DbgPara[dbg]['exe'])
+    cmdetmp = osp.join(REPREF, conf['BINCMDE'][0])
+    eletmp  = osp.join(REPREF, conf['BINELE'][0])
 
     # 2. ----- read profile values
     # it's valid because exec, cmde and ele must appear only once
@@ -242,13 +243,13 @@ def RunAster(run, *args):
     iret = 0
     if 'make_exec' in prof['actions']:
         run.DBG(u'Start make_exec action')
-        exetmp = os.path.join(reptrav, 'aster.exe')
+        exetmp = osp.join(reptrav, 'aster.exe')
         tit = _(u'Compilation of source files')
         run.Mess(tit, 'TITLE')
         run.timer.Start(tit)
 
-        repact = os.path.join(reptrav, 'make_exec')
-        repobj = os.path.join(repact, 'repobj')
+        repact = osp.join(reptrav, 'make_exec')
+        repobj = osp.join(repact, 'repobj')
         run.MkDir(repact)
         lf = []
         for typ in ('c', 'f', 'f90'):
@@ -261,7 +262,7 @@ def RunAster(run, *args):
         # liste des fichiers surchargés
         vers = get_aster_version(REPREF)
         vers = '.'.join(vers[:3])
-        fsurch = os.path.join(repact, 'surchg.f')
+        fsurch = osp.join(repact, 'surchg.f')
         listsurcharge(vers, fsurch, lf)
         jret, lbi = build.Compil('F', fsurch, repobj, dbg, repact)
         run.timer.Stop(tit)
@@ -270,14 +271,14 @@ def RunAster(run, *args):
         tit = _(u'Build executable')
         run.Mess(tit, 'TITLE')
         run.timer.Start(tit)
-        libaster = os.path.join(REPREF, DbgPara[dbg]['libast'])
-        libferm  = os.path.join(REPREF, DbgPara[dbg]['libfer'])
+        libaster = osp.join(REPREF, DbgPara[dbg]['libast'])
+        libferm  = osp.join(REPREF, DbgPara[dbg]['libfer'])
         # for backward compatibility
         if run.IsDir(libaster):
-            libaster = os.path.join(libaster, 'lib_aster.lib')
+            libaster = osp.join(libaster, 'lib_aster.lib')
         if run.IsDir(libferm):
-            libferm = os.path.join(libferm, 'ferm.lib')
-        lobj = glob(os.path.join(repobj, '*.o'))
+            libferm = osp.join(libferm, 'ferm.lib')
+        lobj = glob(osp.join(repobj, '*.o'))
         # build an archive if there are more than NNN object files
         if len(lobj) > 500:
             run.timer.Stop(tit)
@@ -313,9 +314,9 @@ def RunAster(run, *args):
     if 'make_cmde' in prof['actions']:
         run.DBG(u'Start make_cmde action')
         tit = _(u"Compilation of commands catalogue")
-        cmdetmp = os.path.join(reptrav, 'cata_commande')
+        cmdetmp = osp.join(reptrav, 'cata_commande')
         run.timer.Start(tit)
-        repact = os.path.join(reptrav, 'make_cmde')
+        repact = osp.join(reptrav, 'make_cmde')
         run.MkDir(repact)
         kargs = { 'exe' : exetmp, 'cmde' : cmdetmp, }
         kargs['capy'] = [l['path'] for l in prof.Get('D', typ='capy')]
@@ -333,7 +334,7 @@ def RunAster(run, *args):
         if prof.Get('R', typ='cmde'):
             cmde = prof.Get('R', typ='cmde')[0]
             iret = run.MkDir(cmde['path'])
-            iret = run.Copy(cmde['path'], os.path.join(cmdetmp, 'cata*.py*'))
+            iret = run.Copy(cmde['path'], osp.join(cmdetmp, 'cata*.py*'))
         run.timer.Stop(tit)
 
     #
@@ -342,12 +343,15 @@ def RunAster(run, *args):
     if 'make_ele' in prof['actions']:
         run.DBG(u'Start make_ele action')
         tit = _(u"Compilation of elements")
-        eletmp = os.path.join(reptrav, 'elem.1')
+        eletmp = osp.join(reptrav, 'elem.1')
         run.timer.Start(tit)
-        repact = os.path.join(reptrav, 'make_ele')
+        repact = osp.join(reptrav, 'make_ele')
         run.MkDir(repact)
         kargs = { 'exe' : exetmp, 'cmde' : cmdetmp, 'ele' : eletmp, }
         kargs['cata'] = [l['path'] for l in prof.Get('D', typ='cata')]
+        lfun = prof.Get('D', typ='unig')
+        if lfun:
+            kargs['unigest'] = build.GetUnigest(lfun[0]['path'])
         if prof.Get('D', typ='py'):
             kargs['py'] = [l['path'] for l in prof.Get('D', typ='py')]
         jret = build.CompilEle(REPREF, repact, **kargs)
@@ -429,7 +433,7 @@ def RunAster(run, *args):
 
             run.Mess(_(u'Code_Aster run ended'), diag)
             # 3.4.5. add .resu/.erre to output for testcases
-            if os.path.exists('fort.15') and os.stat('fort.15').st_size > 0:
+            if osp.exists('fort.15') and os.stat('fort.15').st_size > 0:
                 run.Mess(_(u'Content of RESU file'), 'TITLE')
                 run.FileCat('fort.8', magic.get_stdout())
                 run.Mess(_(u'Content of ERROR file'), 'TITLE')
@@ -476,9 +480,9 @@ def RunAster(run, *args):
     #
     if 'exec_crs' in prof['actions']:
         run.DBG(u'Start exec_crs action')
-        repsrc = os.path.join(reptrav, 'sources')
-        reptmp = os.path.join(reptrav, 'tmp')
-        fmsg = os.path.join(reptrav, 'messages')
+        repsrc = osp.join(reptrav, 'sources')
+        reptmp = osp.join(reptrav, 'tmp')
+        fmsg = osp.join(reptrav, 'messages')
         run.MkDir(repsrc)
 
         tit = _(u'Copy of source files')
@@ -487,7 +491,7 @@ def RunAster(run, *args):
         lf  = prof.Get('D', typ='f')
         for rep in [l['path'] for l in lf]:
             if run.IsDir(rep):
-                src = os.path.join(rep, '*.f')
+                src = osp.join(rep, '*.f')
             else:
                 src = rep
             iret = run.Copy(repsrc, src)
@@ -504,7 +508,7 @@ def RunAster(run, *args):
 
         run.timer.Start(tit)
         iret, output = run.Shell(' '.join(cmd), follow_output=True)
-        if os.path.exists(fmsg):
+        if osp.exists(fmsg):
             run.Mess(_(u'content of messages files :'))
             f = open(fmsg, 'r')
             print3(f.read())
@@ -521,9 +525,9 @@ def RunAster(run, *args):
 
     if 'exec_crp' in prof['actions']:
         run.DBG(u'Start exec_crp action')
-        repsrc = os.path.join(reptrav, 'sources')
-        reptmp = os.path.join(reptrav, 'tmp')
-        fmsg = os.path.join(reptrav, 'messages')
+        repsrc = osp.join(reptrav, 'sources')
+        reptmp = osp.join(reptrav, 'tmp')
+        fmsg = osp.join(reptrav, 'messages')
         run.MkDir(repsrc)
 
         tit = _(u'Copy of source files')
@@ -532,7 +536,7 @@ def RunAster(run, *args):
         lf  = prof.Get('D', typ='f')
         for rep in [l['path'] for l in lf]:
             if run.IsDir(rep):
-                src = os.path.join(rep, '*.f')
+                src = osp.join(rep, '*.f')
             else:
                 src = rep
             iret = run.Copy(repsrc, src)
@@ -555,7 +559,7 @@ def RunAster(run, *args):
 
         run.timer.Start(tit)
         iret, output = run.Shell(' '.join(cmd), follow_output=True)
-        if os.path.exists(fmsg):
+        if osp.exists(fmsg):
             run.Mess(_(u'content of messages files :'))
             f = open(fmsg, 'r')
             print3(f.read())
@@ -589,7 +593,7 @@ def StartNow(run, *args):
         run.parser.error(_(u"'--%s' requires at least one argument") % run.current_action)
 
     # build export
-    lf = [os.path.abspath(f) for f in args]
+    lf = [osp.abspath(f) for f in args]
     prof = build_export_from_files(run, lf, with_results=True)
 
     # development files
@@ -597,8 +601,8 @@ def StartNow(run, *args):
     if surch_pyt:
         for obj in surch_pyt.split(','):
             prof.Set('D', {
-                'path' : os.path.abspath(obj), 'type' : 'py',
-                'ul'   : '0', 'isrep' : os.path.isdir(os.path.abspath(obj)),
+                'path' : osp.abspath(obj), 'type' : 'py',
+                'ul'   : 0, 'isrep' : osp.isdir(osp.abspath(obj)),
                 'compr' : False,
             })
     exetmp = None
@@ -606,14 +610,14 @@ def StartNow(run, *args):
     if surch_fort:
         for obj in surch_fort.split(','):
             prof.Set('D', {
-                'path' : os.path.abspath(obj), 'type' : 'f',
-                'ul'   : '0', 'isrep' : os.path.isdir(os.path.abspath(obj)),
+                'path' : osp.abspath(obj), 'type' : 'f',
+                'ul'   : 0, 'isrep' : osp.isdir(osp.abspath(obj)),
                 'compr' : False,
             })
         exetmp = get_tmpname(run, run['tmp_user'], basename='executable')
         prof.Set('DR', {
             'path' : exetmp, 'type' : 'exec',
-            'ul'   : '0', 'isrep' : False, 'compr' : False,
+            'ul'   : 0, 'isrep' : False, 'compr' : False,
         })
 
     if exetmp is not None:
