@@ -116,7 +116,7 @@ def execute(reptrav, multiple=False, with_dbg=False, only_env=False,
     cmd = []
     cmd.append(osp.join(conf['REPPY'][0], conf['ARGPYT'][0]))
     cmd.extend(conf['ARGEXE'])
-    cmd.append('-commandes fort.1 -rep none')
+    cmd.append('-commandes fort.1')
     cmd_memtps = {}
     for k, v in prof.args.items():
         if k == 'args':
@@ -343,7 +343,7 @@ export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:.
             iret, exec_output = run.Shell(cmd_exec, follow_output=follow_output, interact=interact)
             if iret != 0:
                 for f in ('fort.6', 'fort.8', 'fort.9'):
-                    run.FileCat(text="""\n <S>_ABNORMAL_ABORT  exit code = %s""" % iret, dest=f)
+                    run.FileCat(text="""\n <I>_EXIT_CODE = %s""" % iret, dest=f)
             if not follow_output and not ctest:
                 print3(exec_output)
 
@@ -475,12 +475,12 @@ def copyfileD(run, df, icomm, ncomm):
     """
     dest = None
     # 1. ----- if logical unit is set : fort.*
-    if df['ul'] != '0' or df['type'] in ('nom',):
-        dest = 'fort.' + df['ul']
+    if df['ul'] != 0 or df['type'] in ('nom',):
+        dest = 'fort.%d' % df['ul']
         if df['type'] == 'nom':
             dest = osp.basename(df['path'])
         # exception for multiple command files (adding _N)
-        if df['ul'] == '1':
+        if df['ul'] == 1:
             icomm += 1
             format = '%%0%dd' % (int(log10(max(1, ncomm))) + 1)
             dest = dest + '.' + format % icomm
@@ -533,10 +533,10 @@ def copyfileR(run, df, copybase=True, alarm=True):
     isdir = False
 
     # 1. ----- files
-    if df['ul'] != '0' or df['type'] in ('nom', 'para'):
+    if df['ul'] != 0 or df['type'] in ('nom', 'para'):
         # if logical unit is set : fort.*
-        if df['ul'] != '0':
-            lf.append('fort.' + df['ul'])
+        if df['ul'] != 0:
+            lf.append('fort.%d' % df['ul'])
         elif df['type'] == 'para':
             fpara = '%s.para' % run['num_job']
             lf.append(fpara)
@@ -614,8 +614,7 @@ def build_test_export(run, conf, REPREF, reptest, test, resutest=None,
                       with_default=True, d_unig=None):
     """Return a profile for a testcase.
     """
-    REPTEST = osp.join(REPREF, conf['SRCTEST'][0])
-    lrep = [REPTEST]
+    lrep = [osp.join(REPREF, dt) for dt in conf['SRCTEST']]
     if reptest:
         lrep.extend(reptest)
     for rep in lrep:
