@@ -128,7 +128,7 @@ VALIDATION
             'fix_in'        : '',
             'date_emission' : date_inverse(issue['_creation']),
         })
-        
+
         # 1a. list of messages or last message
         if l_rep != None and len(l_rep) > 0:
             if not type(l_rep) in EnumTypes:
@@ -139,11 +139,11 @@ VALIDATION
             d_msg = issue.GetLinks()
             imsg = max(d_msg.keys())
             dico['reponse'] = d_msg[imsg]['_summary'] + '...'
-        
+
         # 1b. text fields
         for k in ('_title', '_validation'):
             dico[k] = convert(dico[k])
-        
+
         # 2. champs OUI/NON
         for key in ('_corrVdev', '_corrVexpl'):
             if dico[key] != None:
@@ -155,15 +155,15 @@ VALIDATION
                 dico[key] = 'OUI   DEPUIS : %s' % dico[key]
             else:
                 dico[key] = 'NON'
-        
+
         # 3. "pour le compte de" field
         if issue['_intervenant'] != None:
             dico['tma'] = self.mask_tma % issue['_intervenant'].GetPrimValue()
-        
+
         # 4. show '_nbJours' field if no intervenant
         if issue['_intervenant'] == None:
             dico['nbjours'] = self.mask_nbjours % issue['_nbJours']
-        
+
         # 5. fixed in...
         val = ""
         if issue['_verCorrVexpl'] != None:
@@ -174,10 +174,10 @@ VALIDATION
             val += issue['_verCorrVdev']
         if val:
             dico['fix_in'] = self.mask_restit % val
-        
+
         # 6. keep only strings
         dico = self.clean_dict(dico)
-        
+
         return dico
 
 
@@ -197,7 +197,7 @@ VALIDATION
         }
         if hasattr(user, 'values'):
             dico = self.clean_dict(user.values.copy())
-        
+
         dico.update({
             'CR'            : self.CR,
             'dateheure'     : now(sep=" - "),
@@ -229,7 +229,7 @@ VALIDATION
         txt = [self.header]
         txt.extend(self.l_bloc)
         txt.append(self.footer)
-        return ''.join(txt)
+        return ''.join([convert(s) for s in txt])
 
 
 
@@ -311,7 +311,7 @@ VALIDATION
         """Initialize histor object.
         """
         HISTOR.__init__(self)
-        
+
         # specific arguments
         self.server_url = kargs.get('url', None)
         self.fmt_url_issue = '%s/issue%%s' % saxutils.escape(self.server_url)
@@ -336,14 +336,14 @@ VALIDATION
         """Represent an issue as a dict object.
         """
         dico = HISTOR.DictIssue(self, issue, l_rep)
-        
+
         # specific fields
         dico['url_issue'] = self.fmt_url_issue % issue['id']
-        
+
         # multi-lines fields
         for k in ('reponse',):
             dico[k] = dico[k].replace(os.linesep, self.CR)
-        
+
         return dico
 
 
@@ -368,13 +368,12 @@ Risque de résultats faux depuis la version : %(_fauxVexpl)s %(_fauxVdev)s
         """Represent an issue as a dict object.
         """
         dico = HISTOR.DictIssue(self, issue, l_rep)
-        
+
         # clean response
         for k in ('reponse',):
-            dico[k] = dico[k].replace(os.linesep, " ")
             dico[k] = re.sub(' +', ' ', dico[k])
             dico[k] = dico[k].strip()
-        
+
         return dico
 
 
