@@ -38,7 +38,7 @@ from asrun.installation import aster_root
 from asrun.common.i18n import _
 from asrun.mystring     import print3, ufmt
 from asrun.core         import RunAsterError, magic
-from asrun.config       import AsterConfig
+from asrun.config       import build_config_of_version
 from asrun.build        import AsterBuild
 from asrun.system       import local_host
 from asrun.update       import AstkUpdate, read_version_list, download_package
@@ -394,8 +394,7 @@ def ShowOP(run, *list_capy):
         run.parser.error(
                 _(u"'--%s' requires one or more arguments") % run.current_action)
     run.PrintExitCode = False
-    ficconf = os.path.join(REPREF, 'config.txt')
-    conf = AsterConfig(ficconf, run)
+    conf = build_config_of_version(run, run['aster_vers'])
     for capy in list_capy:
         capy = capy.replace('.capy', '')
         nf = os.path.join(REPREF, conf['SRCCAPY'][0], 'commande', capy + '.capy')
@@ -491,8 +490,7 @@ def Get(run, *args, **kwargs):
         user, mach = run.system.getuser_host()
         REPREF = run.get_version_path(run['aster_vers'])
         # répertoires
-        ficconf = os.path.join(REPREF, 'config.txt')
-        conf  = AsterConfig(ficconf, run)
+        conf = build_config_of_version(run, run['aster_vers'])
         RC    = os.path.join(REPREF, conf['SRCC'][0])
         RFORT = os.path.join(REPREF, conf['SRCFOR'][0])
         RF90  = os.path.join(REPREF, conf['SRCF90'][0])
@@ -719,16 +717,13 @@ def get_aster_version(vers):
     """Return the Code_Aster version named `vers`.
     """
     run = magic.run
-    repref = run.get_version_path(vers)
-    ficconf = os.path.join(repref, 'config.txt')
-    # if file don't exist, suppose default value
-    if os.path.exists(ficconf):
-        conf = AsterConfig(ficconf, run)
-        bibpyt = conf['SRCPY'][0]
+    conf = build_config_of_version(run, vers, error=False)
+    if conf:
+        bibpyt = conf.get_with_absolute_path('SRCPY')[0]
     else:
-        bibpyt = 'bibpyt'
+        bibpyt = osp.join(run.get_version_path(vers), 'bibpyt')
     # ----- properties.py
-    f = os.path.join(repref, bibpyt, 'Accas', 'properties.py')
+    f = os.path.join(bibpyt, 'Accas', 'properties.py')
     if not os.path.isfile(f):
         run.Mess(ufmt(_(u'file not found : %s'), f), '<F>_FILE_NOT_FOUND')
     mydict = {}
@@ -748,11 +743,10 @@ def MakeAster(run, *args):
     """
     run.check_version_setting()
     REPREF = run.get_version_path(run['aster_vers'])
-    if not run.get('config'):
-        fconf = os.path.join(REPREF, 'config.txt')
-    else:
-        fconf = os.path.abspath(run['config'])
-    conf = AsterConfig(fconf, run)
+    fconf = run.get('config')
+    if fconf:
+        fconf = osp.abspath(fconf)
+    conf = build_config_of_version(run, run['aster_vers'], fconf)
 
     # check arguments
     target = 'all'
@@ -793,8 +787,8 @@ def MakeAster(run, *args):
                         (run.get_version_path(run['aster_vers']), local_host)
             run.Mess(errmsg, '<F>_BUILD_FAILED')
         else:
-            subject = _(u'Built of %s ended successfully on %s') \
-                        % (run.get_version_path(run['aster_vers']), local_host)
+            subject = ufmt(_(u'Built of %s ended successfully on %s'),
+                           run.get_version_path(run['aster_vers']), local_host)
             mail.append(subject)
             run.ExitOnFatalError = True
             run.Mess(os.linesep.join(mail), 'OK')
@@ -805,7 +799,7 @@ def MakeAster(run, *args):
 
     elif target == 'clean':
         if len(param) == 0:
-            l_clean = ['BIN_NODBG', 'BIN_DBG', 'BINCMDE', 'BINELE', 'BINPICKLED',
+            l_clean = ['BIN_NODBG', 'BIN_DBG', 'BINCMDE', 'BINCMDE_ZIP', 'BINELE', 'BINPICKLED',
                     'BINLIB_NODBG', 'BINLIB_DBG', 'BINSHLIB_NODBG', 'BINSHLIB_DBG',
                     'BINLIBF_NODBG', 'BINLIBF_DBG', 'BINSHLIBF_NODBG', 'BINSHLIBF_DBG',
                     'BINOBJ_NODBG', 'BINOBJF_NODBG', 'BINOBJ_DBG', 'BINOBJF_DBG']
@@ -1019,11 +1013,10 @@ def Update(run, *args, **kwargs):
     """
     run.check_version_setting()
     REPREF = run.get_version_path(run['aster_vers'])
-    if not run.get('config'):
-        fconf = os.path.join(REPREF, 'config.txt')
-    else:
-        fconf = os.path.abspath(run['config'])
-    conf   = AsterConfig(fconf, run)
+    fconf = run.get('config')
+    if fconf:
+        fconf = osp.abspath(fconf)
+    conf = build_config_of_version(run, run['aster_vers'], fconf)
     build  = AsterBuild(run, conf)
 
     # check arguments
@@ -1383,11 +1376,10 @@ def CopyVersion(run, version, dest, **kwargs):
     """
     REPREF  = os.path.join(aster_root, run.get_version_path(version))
     REPDEST = os.path.join(aster_root, dest)
-    if not run.get('config'):
-        fconf = os.path.join(REPREF, 'config.txt')
-    else:
-        fconf = os.path.abspath(run['config'])
-    conf = AsterConfig(fconf, run)
+    fconf = run.get('config')
+    if fconf:
+        fconf = osp.abspath(fconf)
+    conf = build_config_of_version(run, version, fconf)
 
     title = ufmt(_(u'Copy %s to %s'), os.path.basename(version), os.path.basename(dest))
     run.timer.Start(title)
@@ -1435,11 +1427,10 @@ def MakeDiag(run, *args):
         run.parser.error(_(u"'--%s' requires at most one argument") % run.current_action)
 
     REPREF = run.get_version_path(run['aster_vers'])
-    if not run.get('config'):
-        fconf = os.path.join(REPREF, 'config.txt')
-    else:
-        fconf = os.path.abspath(run['config'])
-    conf   = AsterConfig(fconf, run)
+    fconf = run.get('config')
+    if fconf:
+        fconf = osp.abspath(fconf)
+    conf = build_config_of_version(run, run['aster_vers'], fconf)
     build  = AsterBuild(run, conf)
 
     run.PrintExitCode = False
@@ -1458,7 +1449,7 @@ def MakeDiag(run, *args):
     fmt_tot  = '-'*12 + ' ' + '-'*18 + ' ' + '-'*10 + ' ' + '-'*10 + ' ' + '-'*10
 
     # 1. ----- Go !
-    l_dirs = run.get('astest_dir', os.path.join(REPREF, conf['SRCTEST'][0]))
+    l_dirs = run.get('astest_dir', ','.join(conf['SRCTEST']))
     l_dirs = [os.path.join(REPREF, os.path.abspath(p.strip())) \
             for p in l_dirs.split(',')]
     # testcases list
@@ -1659,7 +1650,7 @@ def GetExport(run, *args):
     REPREF = run.get_version_path(run['aster_vers'])
     run.PrintExitCode = False
     ficconf = os.path.join(REPREF, 'config.txt')
-    conf = AsterConfig(ficconf, run)
+    conf = build_config_of_version(run, run['aster_vers'])
 
     prof = build_test_export(run, conf, REPREF, reptest=[], test=args[0])
     print3(prof.get_content())
@@ -1669,7 +1660,7 @@ def get_vers(fich, debug=False):
     """Extract the version which produced 'resu'/'erre' file.
     """
     vers = ''
-    exp = re.compile('Version.* ([0-9]+\.[0-9]+\.[0-9]+) ', re.M | re.I)
+    exp = re.compile('Version.* ([0-9]+\.[0-9\.]+) ', re.M | re.I)
     if os.path.isfile(fich):
         l_v = exp.findall(open(fich, 'r').read())
         if len(l_v) > 0:
