@@ -30,7 +30,7 @@ from math import ceil
 from asrun.core import magic
 from asrun.common.i18n import _
 from asrun.common_func import same_hosts2, is_localhost2
-from asrun.common.utils import Enum, YES, hms2s
+from asrun.common.utils import Enum, hms2s, YES, YES_VALUES
 from asrun.common.sysutils import FileName, local_user, local_full_host, on_64bits, \
                                   PASSWD_SEP, PATH_SEP, HOST_SEP
 from asrun.mystring import print3, convert_list, split_endlines, ufmt
@@ -88,7 +88,7 @@ class ExportEntry(FileName):
                     basn = _defconv(self.path)
                 else:
                     basn = convert(self.path)
-                magic.run.DBG("relocate %s to %s" % (self._path, osp.join(newdir, basn)),
+                magic.run.DBG(ufmt("relocate %s to %s", self._path, osp.join(newdir, basn)),
                     stack_id=2)
                 self.set_pathname(osp.join(newdir, basn))
 
@@ -388,7 +388,7 @@ class AsterProfil:
         for k in l_k:
             if not dico.has_key(k):
                 self._mess(_(u"key '%s' missing") % k, '<F>_PROGRAM_ERROR')
-        dico['ul'] = str(dico['ul'])
+        dico['ul'] = int(dico['ul'])
         for what in l_what:
             what.append(dico)
         # update content
@@ -466,7 +466,7 @@ class AsterProfil:
                                 'type'  : spl[1],
                                 'path'  : spl[2],
                                 'isrep' : typ == 'R',
-                                'ul'    : spl[4],
+                                'ul'    : int(spl[4]),
                                 'compr' : spl[3].find('C') > -1,
                             }
                             if spl[3].find('D')>-1:
@@ -685,8 +685,9 @@ class AsterProfil:
             facW = 8
         else:
             facW = 4
-        self['memjob'] = memory * 1024
-        self.args['memjeveux'] = 1.0 * memory / facW
+        self['memjob'] = int(memory * 1024)
+        ratio = (float(self['mem_aster'][0] or 100.)) / 100.
+        self.args['memjeveux'] = 1.0 * memory / facW * ratio
 
     def from_remote_server(self, ignore_types=None):
         """Change local pathnames to be visible from a remote server.
@@ -720,7 +721,10 @@ class AsterProfil:
             mode = getattr(MODES, mode.upper(), -1)
         if not MODES.exists(mode):
             raise ValueError("not a valid mode : %s" % mode)
-        self["mode"] = MODES.get_id(mode).lower()
+        mode = MODES.get_id(mode).lower()
+        if self.run and self.run.get(mode) not in YES_VALUES:
+            mode = "interactif"
+        self["mode"] = mode
 
     def get_timeout(self):
         """Return timeout value from profile.
