@@ -142,8 +142,8 @@ class AsterRun:
 
         self.user_rc = osp.join(get_home_directory(), self.rcdir, 'prefs')
         self._read_rc(osp.join(confdir, 'asrun'), self.config, mcsimp=['noeud',])
-        self._read_rc(osp.join(confdir, 'aster'), self.config, optionnal=True, mcsimp=['vers',])
-        self._read_rc(osp.join(confdir, 'agla'),  self.config, optionnal=True)
+        self._read_rc(osp.join(confdir, 'aster'), self.config, optional=True, mcsimp=['vers',])
+        self._read_rc(osp.join(confdir, 'agla'),  self.config, optional=True)
         self._init_rc()
 
         # add user plugins directory
@@ -226,20 +226,25 @@ class AsterRun:
             pass
 
         if not osp.isfile(ficrc):
-            # ----- create ressources file
+            # create ressources file
             from asrun.client import ClientConfig
-            client = ClientConfig(self.rcdir)
-            client.init_user_resource(osp.basename(ficrc))
-        # ----- read user ressource file
-        self._read_rc(ficrc, self.config, mcsimp=['vers', 'noeud'])
+            try:
+                client = ClientConfig(self.rcdir)
+                client.init_user_resource(osp.basename(ficrc))
+            except (OSError, IOError):
+                # permission denied into rcdir
+                pass
+        if osp.isfile(ficrc):
+            # read user ressource file if exists
+            self._read_rc(ficrc, self.config, mcsimp=['vers', 'noeud'], optional=True)
         self._check_config()
 
 
-    def _read_rc(self, ficrc, destdict, optionnal=False, mcsimp=None):
+    def _read_rc(self, ficrc, destdict, optional=False, mcsimp=None):
         """Read a ressource file and store variables to 'destdict'."""
         if osp.isfile(ficrc):
             read_rcfile(ficrc, destdict, mcsimp=mcsimp)
-        elif not optionnal:
+        elif not optional:
             print3(ufmt(_(u'file not found : %s'), ficrc))
             self.Sortie(4)
 
@@ -330,7 +335,7 @@ class AsterRun:
             actions_descr  : description of each action :
                 key   = action name,
                 value = {syntax, help, method}
-        Optionnal arguments :
+        optional arguments :
             actions_order  : order to display actions in help (default to '' :
                 arbitrary order of dico.keys method)
             group_options  : add a option group to list options (default to True)
@@ -508,20 +513,43 @@ class AsterRun:
         return get_unique_id(self['num_job'], num)
 
 
+    def get_versions_dict(self):
+        """Return a dict of the available versions indexed with their label.
+        The versions are defined in etc/codeaster/aster + $HOME/.astkrc/prefs."""
+        dict_vers = {}
+        if self['vers']:
+            for vname in self['vers'].split():
+                if len(vname.split(':')) == 2:
+                    key, vname = vname.split(':')
+                else:
+                    key = osp.basename(vname)
+                if dict_vers.get(key) is not None:
+                    self.Mess(_(u"%s is already known as %s (%s is ignored). Check your configuration file : %s") \
+                        % (key, dict_vers[key], vname, osp.join(confdir, "aster")), "<A>_ALARM")
+                    continue
+                dict_vers[key] = vname
+        return dict_vers
+
+    def get_ordered_versions(self):
+        """Return the version labels ordered as defined in the
+        configuration files."""
+        lv = []
+        if self['vers']:
+            for vname in self['vers'].split():
+                if len(vname.split(':')) == 2:
+                    key, vname = vname.split(':')
+                else:
+                    key = osp.basename(vname)
+                if key not in lv:
+                    lv.append(key)
+        return lv
+
     def get_version_path(self, label, root=aster_root):
         """Return full path to the version named 'label'."""
         if not label:
             return None
-        dv = {}
-        if self['vers']:
-            for v in self['vers'].split():
-                key = osp.basename(v)
-                if dv.get(key) is not None:
-                    self.Mess(_(u"%s is already known as %s (%s is ignored). Check your configuration file : %s") \
-                        % (key, dv[key], v, osp.join(confdir, "aster")), "<A>_ALARM")
-                    continue
-                dv[key] = v
-        return osp.join(root, dv.get(label, label))
+        dict_vers = self.get_versions_dict()
+        return osp.join(root, dict_vers.get(label, label))
 
 
     def PostConf(self):
@@ -619,7 +647,7 @@ class AsterRun:
             # unknown flag
             if g1 == -9:
                 coderr = '<I> '+coderr
-        print3(fmt % (coderr, msg))
+        print3(ufmt(fmt, coderr, msg))
         magic.get_stdout().flush()
         # ----- store in print_on_exit
         if store or (not self.ExitOnFatalError and g1 >= self.GetGrav('<S>')):
@@ -676,6 +704,7 @@ class AsterRun:
         # helps to locate error in PROGRAM_ERROR case or in verbose mode
         if self.diag == '<F>_PROGRAM_ERROR' \
                 or (exit_code != 0 and (self['debug'] or self['verbose'] or not self.ExitOnFatalError)):
+            self.DBG(u'### Raise RunAsterError exception because of program error or debug mode ###')
             raise RunAsterError, exit_code
 
         # stop all timers
