@@ -185,7 +185,8 @@ def get_files_to_change(rootdir, prefix):
    log.debug("... searching from %s", rootdir + prefix2etc(prefix))
    # glob ignores files beginning with a dot (.mysql_connect)
    files = []
-   files.extend(glob(os.path.join(rootdir +prefix, 'bin', '*')))
+   for f in ('as_run*', 'astk', 'bsf', 'codeaster*', 'parallel_cp', 'auto_update.cron'):
+      files.extend(glob(os.path.join(rootdir + prefix, 'bin', f)))
    files.extend(glob(os.path.join(rootdir + prefix2etc(prefix), 'codeaster', '*')))
    files.extend(glob(os.path.join(rootdir + prefix2etc(prefix), 'codeaster', 'astkrc', '*')))
    files.extend(glob(os.path.join(rootdir + prefix, 'share', 'codeaster', 'asrun', 'data', '*')))
