@@ -8,7 +8,7 @@ from distutils import log
 from distutils import sysconfig
 
 from configuration.util import execute, less_than_version, get_function, move_tree, \
-                           remove_tree, remove_empty_dirs
+                           remove_tree, remove_empty_dirs, tick
 
 
 def remove_1_7(prefix, dest, version):
@@ -25,7 +25,9 @@ def remove_last(prefix, dest, version):
                                            'parallel_cp', 'show', 'get', 'showop', 'getop')] \
        + ['etc/codeaster', 'share/codeaster/asrun', 'share/codeaster/GPL.txt', 'lib/astk'] \
        + [os.path.join(python_lib, 'asrun'), os.path.join(python_lib, 'astk-%s.egg-info' % version)]
-   move_tree(prefix, d_f, dest, preserve_symlinks=True)
+   tick()
+   move_tree(prefix, d_f, dest, preserve_symlinks=True, same_device=True)
+   tick()
 
 
 def remove_previous_main(prefix, version):
@@ -34,6 +36,7 @@ def remove_previous_main(prefix, version):
       version = 'unknown'
    destination = os.path.join(prefix, 'share', 'codeaster', 'backup', 'backup_%s' % version)
    if os.path.exists(destination):
+      tick()
       remove_tree(destination)
    os.makedirs(destination)
    log.info("backup previous installation into %s", destination)
@@ -42,9 +45,13 @@ def remove_previous_main(prefix, version):
       ('0.0.0', remove_1_7),
       ('1.8.0', remove_last),
    )
+   tick()
    func = get_function(functions, version)
+   tick()
    func(prefix, destination, version)
+   tick()
    remove_empty_dirs(prefix)
+   tick()
    return destination
 
 
